@@ -256,7 +256,7 @@ class DataTypes:
         }, ptyp2)
 
     @staticmethod
-    def dict(schema: dict, ptyp2: dict or None = None) -> dict:
+    def dict(ptyp2: dict or None = None) -> dict:
         return DataTypes.type({
             'type': 'dict',
             'message': {
@@ -265,6 +265,39 @@ class DataTypes:
             }
         }, ptyp2)
 
+    @staticmethod
+    def date(ptyp2: dict or None = None) -> dict:
+        return DataTypes.type({
+            'type': 'date',
+            'format': '%Y-%m-%d',
+            'message': {
+                lang.EN: "{name} must be a valid date with format YYYY-MM-DD",
+                lang.ES: "{name} debe ser una fecha válida con el formato YYYY-MM-DD",
+            }
+        }, ptyp2)
+
+    @staticmethod
+    def time(ptyp2: dict or None = None) -> dict:
+        return DataTypes.type({
+            'type': 'time',
+            'format': '%H:%M:%S',
+            'message': {
+                lang.EN: "{name} must be a valid time with format HH:MM:SS",
+                lang.ES: "{name} debe ser una hora válida con el formato HH:MM:SS",
+            }
+        }, ptyp2)
+
+    @staticmethod
+    def datetime(ptyp2: dict or None = None) -> dict:
+        return DataTypes.type({
+            'type': 'datetime',
+            'format': '%Y-%m-%d %H:%M:%S',
+            'message': {
+                lang.EN: "{name} must be a valid date and time with format YYYY-MM-DD HH:MM:SS",
+                lang.ES: "{name} debe ser una fecha y hora válida con el formato YYYY-MM-DD HH:MM:SS",
+            }
+        }, ptyp2)
+
     @staticmethod
     def mandatory(ptype: dict) -> dict:
         return DataTypes.type(ptype, {'mandatory': True})
